**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* // 2 GENERATION OF VIGNETTE TEXTS
*************************************************************************

*****************************************
// #1: LOAD Data 
*****************************************

use setup, clear

*****************************************
// #2: GENERATE TEXT PHRASES & SENTENCES
*****************************************

// For vignettes consisting of running text, you have to translate the numeric 
// levels of the single dimensions into the vignette phrases. 
// For that, you should create  string variables that contain the vignette texts.
// It is recommendable to split the vignette texts in single sentences. 


**** Vignette sentence 1  

** First, generate the single text phrases of the first sentence

gen phrase_A1 = "error"
// this is only to have later on an easy possiblity to 
// check if all levels were considered!
	replace phrase_A1 = "A 25-year-old man" if age ==25 & sex == 1
	replace phrase_A1 = "A 30-year-old man" if age ==30 & sex == 1
	replace phrase_A1 = "A 35-year-old man" if age ==35 & sex == 1
	replace phrase_A1 = "A 40-year-old man" if age ==40 & sex == 1
	replace phrase_A1 = "A 45-year-old man" if age ==45 & sex == 1
	replace phrase_A1 = "A 50-year-old man" if age ==50 & sex == 1
	replace phrase_A1 = "A 55-year-old man" if age ==55 & sex == 1
	replace phrase_A1 = "A 60-year-old man" if age ==60 & sex == 1

	replace phrase_A1 = "A 25-year-old woman" if age ==25 & sex == 2
	replace phrase_A1 = "A 30-year-old woman" if age ==30 & sex == 2
	replace phrase_A1 = "A 35-year-old woman" if age ==35 & sex == 2
	replace phrase_A1 = "A 40-year-old woman" if age ==40 & sex == 2
	replace phrase_A1 = "A 45-year-old woman" if age ==45 & sex == 2
	replace phrase_A1 = "A 50-year-old woman" if age ==50 & sex == 2
	replace phrase_A1 = "A 55-year-old woman" if age ==55 & sex == 2
	replace phrase_A1 = "A 60-year-old woman" if age ==60 & sex == 2

gen phrase_A2 = "error" 
	replace phrase_A2 = "without vocational training" if degree ==1
	replace phrase_A2 = "with vocational training" if degree ==2
	replace phrase_A2 = "with a university degree" if degree ==3

gen phrase_A3 ="error" 
	replace phrase_A3 ="has no children." if children == 0 
	replace phrase_A3 ="has one child." if children == 1 
	replace phrase_A3 ="has two children." if children == 2 
	replace phrase_A3 ="has three children." if children == 3 
	replace phrase_A3 ="has four children." if children == 4 

** Check if you considered all levels: 

assert phrase_A1 ~= "error"  
assert phrase_A2 ~= "error"
assert phrase_A3 ~= "error"


** Combine the single phrases to the first sentence: 

gen vigA = phrase_A1 +" "+ phrase_A2 +" "+ phrase_A3  

** Check whether the texts are correct (e.g. spelling, no missing space, ...)

fre vigA

* For large vignette samples you may check only the first 100 cases 

fre vigA in 1/100

** Delete the single phrases, you do not need them any more

drop phrase_A1 - phrase_A3

/******* 
 Note: string variables are combined with +; you can also
add any text that does not vary accross the vignettes by +"text". 

There are many other possibilities for creating the vignette texts. 
For example, to create the first phrase you could also proceed like this:  

gen sex_str = " man" if sex == 1
replace sex_str = " woman" if sex == 2
tostring age, gen(age_str)  // creates a string variable with the age 
gen phrase_A1 = "A " +age_str+"-year-old" +sex_str

you can try this; 
in case you already created phrase_A1 you first have to drop it.


*******/


************************************
**** Vignette sentences 2 and 3 
**** (because sentence 3 is only a very short one we store both
**** sentences within one variable, which we name vigB)

gen phrase_B1 = "error"
	replace phrase_B1 = "He " if sex == 1
	replace phrase_B1 = "She " if sex == 2

gen phrase_B2 = "error"
	replace phrase_B2 = "works as an unskilled worker" 	  if job == 1  
	replace phrase_B2 = "works as a doorman" 			  if job == 2 & sex == 1
	replace phrase_B2 = "works as a doorwoman" 			  if job == 2 & sex == 2
	replace phrase_B2 = "works as an engine driver" 	  if job == 3  
	replace phrase_B2 = "works as a clerk" 				  if job == 4  
	replace phrase_B2 = "works as a hairdresser" 		  if job == 5  
	replace phrase_B2 = "works as a social worker" 		  if job == 6  
	replace phrase_B2 = "works as a software programmer"  if job == 7  
	replace phrase_B2 = "works as an electrical engineer" if job == 8  
	replace phrase_B2 = "works as a manager"	 		  if job == 9  
	replace phrase_B2 = "works as a medical doctor"		  if job == 10  

gen phrase_B3 = "error"
	replace phrase_B3 ="and has gained only a little job experience." if experience == 1
	replace phrase_B3 ="and has gained a lot of job experience." if experience == 2 

gen phrase_B4 = "error"
	replace phrase_B4 = "has worked for the company for a short time." if tenure == 1
	replace phrase_B4 = "has worked for the company for a long time." if tenure == 2
	
	
assert phrase_B1 ~="error"
assert phrase_B2 ~="error"
assert phrase_B3 ~="error"	
assert phrase_B4 ~="error"
	

gen vigB = phrase_B1 + phrase_B2 +" " +phrase_B3 +" " +phrase_B1 + phrase_B4

* Note: The first phrase ("He" or "She") is used twice in this case.

fre vigB

drop phrase_B1 - phrase_B4

****** Vignette sentence 4

gen phrase_C1 = "error"
replace phrase_C1 ="His" if sex ==1 
replace phrase_C1 ="Her" if sex ==2

gen phrase_C2 = "error" 
replace phrase_C2 = "500 Euros (before tax and extra charges)." if income == 500
replace phrase_C2 = "950 Euros (before tax and extra charges)." if income == 950
replace phrase_C2 = "1,200 Euros (before tax and extra charges)." if income == 1200
replace phrase_C2 = "1,500 Euros (before tax and extra charges)." if income == 1500
replace phrase_C2 = "2,500 Euros (before tax and extra charges)." if income == 2500
replace phrase_C2 = "3,800 Euros (before tax and extra charges)." if income == 3800
replace phrase_C2 = "5,400 Euros (before tax and extra charges)." if income == 5400
replace phrase_C2 = "6,800 Euros (before tax and extra charges)." if income == 6800
replace phrase_C2 = "10,000 Euros (before tax and extra charges)." if income == 10000
replace phrase_C2 = "15,000 Euros (before tax and extra charges)." if income == 15000

assert phrase_C1 ~="error"
assert phrase_C2 ~="error"

gen vigC = phrase_C1 + " monthly gross earnings total " +phrase_C2

fre vigC 

drop phrase_C1
drop phrase_C2

*****************************************
// #3: SAVE & EXPORT DATA
*****************************************

** Save the vignette texts: 

save vignettetexts_1, replace


** Optional: you might list the vignettes in a text editor 	         *

// This might be helpful to check if everything was well done

log using vignettetexts.log , replace
list vigA vigB vigC, nod notrim string(244)
log close

// You can also copy the resulting vignette texts to a text-processing software
// like Microsoft Word. 
// For their further use, you will have to edit the 
// texts, as there might be some paragraphs or double spaces you will not need, 
// or maybe also some characters like ">" that are misplaced within the 
// vignette texts. You can simply achieve this by using the replace-option 
// in Word.  

* One way to put the vignettes to Word would be:

capture net install listtab, from(http://fmwww.bc.edu/RePEc/bocode/l) //installs ado
listtab id_vignette vigA vigB vigC using vignettes.doc, ///
replace headlines("Vignette IDs and Vignette texts:") del(" ")

*****************************************
// #4: RESHAPE TO WIDE, RANDOM ORDER
*****************************************

// Often, you will have to reshape the vignette texts for their further use 
// into a wide format; 
// For example, this is needed for the implementation of vignette texts in 
// PAPI or CASI questionnaires. 


use vignettetexts_1, clear
drop id_vignette
* you may also drop the numeric variables: 
drop sex - income

reshape wide vigA - vigC,  i(deck) j(vignr)

// Note: the last one or two digits of the names of the variables now 
// indicate the vignette deck, reaching from 1 up to 12.

save vignette_wide1, replace 

*****************************************
// #5: DATA EXPORT
*****************************************

* You may export the data to an Excel sheet to use them for 
** PAPI questionnares or the programming of CAWI and CAPI questionnaires

export excel using "vignette_wide", firstrow(variables) replace

